/*
 * This file is part of rolas.
 *
 * Copyright © 2018 Canek Peláez Valdés
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program. If not, see <http://www.gnu.org/licenses/>.
 */

namespace Rolas.Compiler {

    /**
     * Abstract class for tokens.
     */
    public abstract class Token : GLib.Object {

        /**
         * Kinds of tokens.
         */
        public enum Kind {
            PAR_LEFT,
            PAR_RIGHT,
            BINARY_OPERATOR,
            UNARY_OPERATOR,
            FIELD,
            COLON,
            STRING;
        }

        /**
         * Sets up a new token.
         * @paran position the position of the token in the input.
         */
        public Token(int position) {
            this.position = position;
        }

        /**
         * The token kind.
         */
        public Kind kind { public get; protected set; }

        /**
         * The token original string.
         */
        public string original { public get; protected set; }

        /**
         * The token position in the input string.
         */
        public int position { public get; construct set; }

        /**
         * Returns the SQL representation of the token.
         * @return the SQL representation of the token.
         */
        public abstract string to_sql();
    }
}
