/*
 * This file is part of rolas.
 *
 * Copyright © 2018 Canek Peláez Valdés
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program. If not, see <http://www.gnu.org/licenses/>.
 */

namespace Rolas.Compiler {

    /**
     * Class for internal representation trees.
     */
    public class Tree : GLib.Object {

        /**
         * The token.
         */
        public Token token { get; set; }

        /**
         * The left tree.
         */
        public Tree left { get; set; }

        /**
         * The right tree.
         */
        public Tree right { get; set; }

        /**
         * Returns a string representation of the tree.
         * @return a string representation of the tree.
         */
        public string to_string() {
            return do_to_string(this, 0);
        }

        /* Indentation string. */
        private static string get_ind(int ind) {
            string r = "";
            for (int i = 0; i < ind; i++) {
                r += "  ";
            }
            return r;
        }

        /* Recursive auxiliar function. */
        private static string do_to_string(Tree? tree, int ind) {
            if (tree == null)
                return "";
            string r = get_ind(ind) + tree.token.original + "\n";
            r += do_to_string(tree.left,  ind+1);
            r += do_to_string(tree.right, ind+1);
            return r;
        }
    }
}
