/*
 * This file is part of rolas.
 *
 * Copyright © 2018 Canek Peláez Valdés
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program. If not, see <http://www.gnu.org/licenses/>.
 */

namespace Rolas.Database {

    /**
     * Class for groups.
     */
    public class Group : GLib.Object {

        /**
         * The group id.
         */
        public int id { public get; private set; }

        /**
         * The group name.
         */
        public string name { public get; private set; }

        /**
         * The group start date.
         */
        public string start_date { public get; private set; }

        /**
         * The group end date.
         */
        public string end_date { public get; private set; }

        /**
         * The number of members in the group.
         */
        public int size { public get { return the_members.size; } }

        /* The members. */
        private Gee.TreeSet<Person> the_members;

        /**
         * Sets up a group.
         * @param id the group id.
         * @param name the group name.
         * @param start_date the group start date.
         * @param end_date the group end date.
         * @param members the group members.
         */
        public Group(int id, string name, string start_date,
                     string end_date, Gee.TreeSet<Person> members) {
            this.id = id;
            this.name = name;
            this.start_date = start_date;
            this.end_date = end_date;
            this.the_members = members;
        }

        /**
         * Whether the group has a particular member.
         * @param person the member to look in the group.
         */
        public bool has_member(Person person) {
            return person in the_members;
        }

        /**
         * Returns an iterable for the group members.
         * @return an iterable for the group members.
         */
        public Gee.Iterable<Person> members() {
            return the_members;
        }
    }
}
