/*
 * This file is part of rolas.
 *
 * Copyright © 2018 Canek Peláez Valdés
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program. If not, see <http://www.gnu.org/licenses/>.
 */

namespace Rolas.Database {

    /**
     * Class for persons.
     */
    public class Person : GLib.Object, Gee.Comparable<Person> {

        /**
         * The person id.
         */
        public int id { public get; private set; }

        /**
         * The person stage name.
         */
        public string stage_name { public get; private set; }

        /**
         * The person real name.
         */
        public string real_name { public get; private set; }

        /**
         * The person birth date.
         */
        public string birth_date { public get; private set; }

        /**
         * The person death date.
         */
        public string death_date { public get; private set; }

        /**
         * Sets up a person.
         * @param id the person id.
         * @param stage_name the person stage name.
         * @param real_name the person real name.
         * @param birth_date the person birth date.
         * @param death_date the person death date.
         */
        public Person(int id, string stage_name, string real_name,
                      string birth_date, string death_date) {
            this.id = id;
            this.stage_name = stage_name;
            this.real_name = real_name;
            this.birth_date = birth_date;
            this.death_date = death_date;
        }

        /**
         * Compares this person with another.
         * @param person the person to compare with.
         * @return the result of comparing this person stage name with the one
         *         received.
         */
        public int compare_to(Person person) {
            return stage_name.collate(person.stage_name);
        }
    }
}
