/*
 * This file is part of rolas.
 *
 * Copyright © 2018 Canek Peláez Valdés
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program. If not, see <http://www.gnu.org/licenses/>.
 */

namespace Rolas.Database {

    /**
     * Class for rolas.
     */
    public class Rola : GLib.Object, Gee.Comparable<Rola> {

        /**
         * The rola path.
         */
        public string path { public get; private set; }

        /**
         * The rola title.
         */
        public string title { public get; private set; }

        /**
         * The rola artist.
         */
        public string artist { public get; private set; }

        /**
         * The rola album.
         */
        public string album { public get; public set; }
        /**
         * The rola track.
         */
        public int track { public get; private set; }

        /**
         * The rola year.
         */
        public int year { public get; public set; }

        /**
         * The rola genre.
         */
        public string genre { public get; private set; }

        /**
         * Sets up a rola.
         * @param path the rola path.
         * @param title the rola title.
         * @param artist the rola artist.
         * @param album the rola album.
         * @param track the rola track.
         * @param year the rola year.
         * @param genre the rola genre.
         */
        public Rola.from_data(string path, string title, string artist,
                              string album, int track, int year,
                              string genre) {
            this.path = path;
            this.title = title;
            this.artist = artist;
            this.album = album;
            this.track = track;
            this.year = year;
            this.genre = genre;
        }

        /**
         * Sets up a rola from a path.
         * @param path the rola path.
         */
        public Rola(string path) {
            var tags = new FileTags(path);
            this.path = path;
            title = tags.title;
            artist = tags.artist;
            album = tags.album;
            track = tags.track;
            year = tags.year;
            genre = Genre.to_string(tags.genre);
            tags = null;
        }

        /**
         * Compares this rola with another.
         * @param rola the rola to compare with.
         * @return the result of comparing this rola path with the one received.
         */
        public int compare_to(Rola rola) {
            return path.collate(rola.path);
        }
    }
}
