/*
 * This file is part of rolas.
 *
 * Copyright © 2018 Canek Peláez Valdés
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program. If not, see <http://www.gnu.org/licenses/>.
 */

namespace Rolas.Database {

    /**
     * Utility functions.
     */
    namespace Util {

        /**
         * Sanitizes a string for labels.
         * @param str the string to sanitize.
         * @return the sanitized string.
         */
        public static string sanitize(string str) {
            return str.replace("&", "&amp;");
        }

        /**
         * Returns the modified time from a file.
         * @param filnename the name of the file.
         * @return the modified time from a file.
         */
        public static GLib.TimeVal get_file_time(string filename) {
            try {
                var file = GLib.File.new_for_path(filename);
                var info = file.query_info("time::modified",
                                           GLib.FileQueryInfoFlags.NONE);
                return info.get_modification_time();
            } catch (GLib.Error e) {
                GLib.warning("There was an error reading from ‘%s’.", filename);
            }
            return GLib.TimeVal();
        }

        /**
         * Sets the modified time for a tile.
         * @param filename the name of the file.
         * @param time the time for the file.
         */
        public static void set_file_time(string filename, GLib.TimeVal time) {
            try {
                var file = GLib.File.new_for_path(filename);
                var info = new GLib.FileInfo();
                info.set_attribute_uint64("time::modified",
                                          (uint64)time.tv_sec);
                info.set_attribute_uint32("time::modified-usec",
                                          (uint32)time.tv_usec);
                info.set_attribute_uint64("time::access",
                                          (uint64)time.tv_sec);
                info.set_attribute_uint32("time::access-usec",
                                          (uint32)time.tv_usec);
                file.set_attributes_from_info(info,
                                              GLib.FileQueryInfoFlags.NONE);
            } catch (GLib.Error e) {
                GLib.warning("There was an error writing to ‘%s’.",
                             filename);
            }
        }
    }
}
