/*
 * This file is part of rolas.
 *
 * Copyright © 2018 Canek Peláez Valdés
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program. If not, see <http://www.gnu.org/licenses/>.
 */

namespace Rolas {

    /**
     * Class for the rolas application.
     */
    public class Application : Gtk.Application {

        /* CSS resource. */
        private const string CSS_RESOURCE =
            "resource:///mx/unam/ciencias/Rolas/style.css";

        /* The application window. */
        private ApplicationWindow window;

        /* Defines the initial state of an application. */
        construct {
            GLib.assert(typeof(Database.Rola) != this.get_type());
            GLib.assert(typeof(Database.Person) != this.get_type());
            application_id = "mx.unam.ciencias.Rolas";
        }

        /**
         * Starts up the application.
         */
        public override void startup() {
            base.startup();
            if (window == null)
                window = new ApplicationWindow(this);

            var action = new GLib.SimpleAction ("shortcuts", null);
            action.activate.connect(shortcuts);
            add_action(action);
            add_accelerator("<Ctrl>S", "app.shortcuts", null);

            action = new GLib.SimpleAction("about", null);
            action.activate.connect(about);
            add_action(action);
            add_accelerator("<Ctrl>B", "app.about", null);

            action = new GLib.SimpleAction ("quit", null);
            action.activate.connect(quit);
            add_action(action);
            add_accelerator("<Ctrl>Q", "app.quit", null);
        }

        /**
         * Activates the application.
         */
        public override void activate() {
            var provider = new Gtk.CssProvider();
            try {
                var file = GLib.File.new_for_uri(CSS_RESOURCE);
                provider.load_from_file(file);
            } catch (GLib.Error e) {
                GLib.warning("There was a problem loading CSS resource");
            }
            Gtk.StyleContext.add_provider_for_screen(Gdk.Screen.get_default(),
                                                     provider, 999);
            window.present();
        }

        /* Ask the window to show the shortcuts dialog. */
        private void shortcuts() {
            window.on_shortcuts_activated();
        }

        /* Ask the window to show the about dialog. */
        private void about() {
            window.on_about_activated();
        }
    }
}
