/*
 * This file is part of rolas.
 *
 * Copyright © 2018 Canek Peláez Valdés
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program. If not, see <http://www.gnu.org/licenses/>.
 */

namespace Rolas {

    /**
     * Class for editing album dialogs.
     */
    [GtkTemplate (ui = "/mx/unam/ciencias/Rolas/edit-album-dialog.ui")]
    public class EditAlbumDialog : Gtk.Dialog {

        /* The name entry. */
        [GtkChild]
        private Gtk.Entry name_entry;

        /* The year entry. */
        [GtkChild]
        private Gtk.Entry year_entry;

        /* The cover image. */
        [GtkChild]
        private Gtk.Image cover_image;

        /**
         * The rola.
         */
        public Database.Rola rola {
            get { return _rola; }
            set { define_rola(value); }
        }
        private Database.Rola _rola;

        /* The database. */
        private Database.Database db;
        /* The changed rolas. */
        private Gee.Set<Database.Rola> changed_rolas;

        /**
         * Sets up a edit album dialog.
         * @param window the transient window.
         */
        public EditAlbumDialog(ApplicationWindow window) {
            GLib.Object(use_header_bar: 1);
            this.transient_for = window;
            cover_image.pixbuf = RolaView.default_cover();
            db = Database.Database.get_database();
        }

        /**
         * The on close activated callback.
         * @return ''false'', always. The dialog never gets destroyed.
         */
        [GtkCallback]
        public bool on_close_activated() {
            hide();
            response(Gtk.ResponseType.CANCEL);
            return false;
        }

        /**
         * The on save clicked callback.
         */
        [GtkCallback]
        public void on_save_clicked() {
            hide();
            changed_rolas = db.update_album(rola,
                                            name_entry.text,
                                            int.parse(year_entry.text));
            response(Gtk.ResponseType.OK);
        }

        /**
         * The on cancel clicked callback.
         */
        [GtkCallback]
        public void on_cancel_clicked() {
            hide();
            response(Gtk.ResponseType.CANCEL);
        }

        /* Defines the rola. */
        private void define_rola(Database.Rola rola) {
            cover_image.pixbuf = RolaView.get_cover(rola);
            name_entry.text = rola.album;
            year_entry.text = "%d".printf(rola.year);
            _rola = rola;
        }

        /**
         * Returns the changed rolas.
         * @return the changed rolas.
         */
        public Gee.Set<Database.Rola> get_changed_rolas() {
            return changed_rolas;
        }
    }
}
