/*
 * This file is part of rolas.
 *
 * Copyright © 2018 Canek Peláez Valdés
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program. If not, see <http://www.gnu.org/licenses/>.
 */

namespace Rolas {

    /**
     * Class for showing band members dialogs.
     */
    [GtkTemplate (ui = "/mx/unam/ciencias/Rolas/show-members-dialog.ui")]
    public class ShowMembersDialog : Gtk.Dialog {

        /* The header. */
        [GtkChild]
        private Gtk.HeaderBar header;

        /* The persons model. */
        [GtkChild]
        private Gtk.ListStore persons_model;

        /* The group. */
        public Database.Group group {
            get { return _group; }
            set { define_group(value); }
        }
        private Database.Group _group;

        /* The database. */
        private Database.Database db;

        /**
         * Sets up a show members dialog.
         * @param window the transient window.
         */
        public ShowMembersDialog(Gtk.Window window) {
            GLib.Object(use_header_bar: 1);
            transient_for = window;
            db = Database.Database.get_database();
        }

        /**
         * The on close activated callback.
         * @return ''false'', always. The dialog never gets destroyed.
         */
        [GtkCallback]
        public bool on_close_activated() {
            on_close_clicked();
            return false;
        }

        /**
         * The on close clicked callback.
         */
        [GtkCallback]
        public void on_close_clicked() {
            hide();
            response(Gtk.ResponseType.CANCEL);
        }

        /* Defines the group. */
        private void define_group(Database.Group group) {
            _group = group;
            header.subtitle = group.name;
            persons_model.clear();
            foreach (var person in group.members()) {
                Gtk.TreeIter iter;
                persons_model.append(out iter);
                persons_model.set(iter,
                                  0, person,
                                  1, person.real_name);
            }
        }
    }
}
